==> igniteui-react-18.2.2-beta.0.tgz: package/esm5/lib/DockManagerLayout.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, markType } from "igniteui-react-core";
import { WCNativeHelper } from "./WCNativeHelper";
import { SplitPane } from "./SplitPane";
import { SplitPaneCollection } from "./SplitPaneCollection";
/**
 * @hidden
 */
var DockManagerLayout = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DockManagerLayout, _super);
    function DockManagerLayout() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.___mustPassByValue = true;
        _this.c = new WCNativeHelper();
        _this.f = null;
        return _this;
    }
    Object.defineProperty(DockManagerLayout.prototype, "h", {
        get: function () {
            var ret_ = this.d.m("name");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.d.u("name", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DockManagerLayout.prototype, "d", {
        get: function () {
            return this.c;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DockManagerLayout.prototype, "nativeElement", {
        get: function () {
            return this.f;
        },
        set: function (a) {
            this.f = a;
            this.c.n = this.f;
        },
        enumerable: false,
        configurable: true
    });
    DockManagerLayout.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(DockManagerLayout.prototype, "a", {
        get: function () {
            var ret_ = this.d.l("rootPane", function (a) { return new SplitPane(); });
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.d.u("rootPane", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DockManagerLayout.prototype, "b", {
        get: function () {
            var ret_ = this.d.j("floatingPanes", function (a) { return new SplitPaneCollection(); }, function (a) { return new SplitPane(); });
            return ret_;
        },
        enumerable: false,
        configurable: true
    });
    DockManagerLayout.$t = markType(DockManagerLayout, 'DockManagerLayout');
    return DockManagerLayout;
}(Base));
export { DockManagerLayout };

==> igniteui-react-18.3.0-beta.0.tgz: package/esm5/lib/DockManagerLayout.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, markType } from "igniteui-react-core";
import { WCNativeHelper } from "./WCNativeHelper";
import { SplitPane } from "./SplitPane";
import { SplitPaneCollection } from "./SplitPaneCollection";
/**
 * @hidden
 */
var DockManagerLayout = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DockManagerLayout, _super);
    function DockManagerLayout() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.___mustPassByValue = true;
        _this.c = new WCNativeHelper();
        _this.f = null;
        return _this;
    }
    Object.defineProperty(DockManagerLayout.prototype, "h", {
        get: function () {
            var ret_ = this.d.n("name");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.d.v("name", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DockManagerLayout.prototype, "d", {
        get: function () {
            return this.c;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DockManagerLayout.prototype, "nativeElement", {
        get: function () {
            return this.f;
        },
        set: function (a) {
            this.f = a;
            this.c.o = this.f;
        },
        enumerable: false,
        configurable: true
    });
    DockManagerLayout.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(DockManagerLayout.prototype, "a", {
        get: function () {
            var ret_ = this.d.m("rootPane", function (a) { return new SplitPane(); });
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.d.v("rootPane", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(DockManagerLayout.prototype, "b", {
        get: function () {
            var ret_ = this.d.k("floatingPanes", function (a) { return new SplitPaneCollection(); }, function (a) { return new SplitPane(); });
            return ret_;
        },
        enumerable: false,
        configurable: true
    });
    DockManagerLayout.$t = markType(DockManagerLayout, 'DockManagerLayout');
    return DockManagerLayout;
}(Base));
export { DockManagerLayout };
